﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Windows.Forms;
using HeuristicLab.MainForm;
using HeuristicLab.Optimization;
using HeuristicLab.Optimization.Views;
using HeuristicLab.Problems.DataAnalysis;

namespace HeuristicLab.DatastreamAnalysis {
  [View("DatastreamAnalysisOptimizer View", "")]
  [Content(typeof(DatastreamAnalysisOptimizer), true)]
  public partial class DatastreamAnalysisOptimizerView : IOptimizerView {
    public DatastreamAnalysisOptimizerView() {
      InitializeComponent();
      Content = new DatastreamAnalysisOptimizer();
    }

    public new DatastreamAnalysisOptimizer Content {
      get { return (DatastreamAnalysisOptimizer)base.Content; }
      set { base.Content = value; }
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null)
        return;

      // TODO
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();

      // TODO
    }

    protected override void DeregisterContentEvents() {
      base.DeregisterContentEvents();
    }

    #region event handlers

    private void ensemblesTab_DragDrop(object sender, DragEventArgs e) {
      if (e.Data.GetDataPresent(HeuristicLab.Common.Constants.DragDropDataFormat)) {
        try {
          // TODO
        }
        catch (Exception ex) {
          MessageBox.Show(ex.Message, "Set ensembles", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
      }
    }

    private void ensemblesTab_DragEnter(object sender, DragEventArgs e) {
      e.Effect = DragDropEffects.None;
      if (!e.Data.GetDataPresent(HeuristicLab.Common.Constants.DragDropDataFormat))
        return;

      var data = e.Data.GetData(HeuristicLab.Common.Constants.DragDropDataFormat);

      // TODO: check if data is taggedEnsembles-data
      if(data is IRegressionEnsembleModel)
        e.Effect = DragDropEffects.Copy;
    }

    private void datastreamTab_DragDrop(object sender, DragEventArgs e) {
      if (e.Data.GetDataPresent(HeuristicLab.Common.Constants.DragDropDataFormat)) {
        try {
          // TODO
        }
        catch (Exception ex) {
          MessageBox.Show(ex.Message, "Set datastream", MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
      }
    }

    private void datastreamTab_DragEnter(object sender, DragEventArgs e) {
      e.Effect = DragDropEffects.None;
      if (!e.Data.GetDataPresent(HeuristicLab.Common.Constants.DragDropDataFormat))
        return;

      var data = e.Data.GetData(HeuristicLab.Common.Constants.DragDropDataFormat);
      if (data is IRegressionProblemData)
        e.Effect = DragDropEffects.Copy;
    }

    #endregion event handlers
  }
}
